@@ -93,11 +93,11 @@ class BaseModel(Model):
                 return (500, f"Unsupported data type {type(data)}")
 
             except IntegrityError as error:
-                print(error)
+                logger.exception("Could not create instance of class %s", cls)
                 return (409, str(error))
 
             except Exception as error:  # pylint: disable=W0703
-                print(error)
+                logger.exception("Could not create instance of class %s", cls)
                 logger.fatal("Could not create course. Reason:", exc_info=True)
                 return (400, str(error))
 
@@ -217,7 +217,4 @@ class NamedMixin:
         Get an instance of this class by its name attribute.
         If no such instance exists, returns None
         """
-        try:
-            return await cls.get(name=name)
-        except DoesNotExist:
-            return None
+        return await cls.get_or_None(name=name)
